@@ -30,6 +30,7 @@ Frame = NamedTuple('Frame', [
 ])
 
 # Contextvars
+DO_TRACE: ContextVar[bool] = ContextVar('DO_TRACE', default=True)
 LEVEL: ContextVar[int] = ContextVar('LEVEL', default=0)
 STACK: ContextVar[List[Frame]] = ContextVar('STACK', default=[])
 
@@ -40,15 +41,19 @@ def get_function_id(function: Callable):
     while hasattr(function, '__wrapped__'):
         function = getattr(function, '__wrapped__')
 
-    try:
-        function_signature: str = str(inspect.signature(function))
-    except ValueError:
-        function_signature = '(...)'
+    signature: str = '(...)'
+    with contextlib.suppress(ValueError):
+        signature = str(inspect.signature(function))
 
-    if function.__module__ not in {'__main__'}:
-        return f'{function.__module__}.{function.__name__}{function_signature}'
+    module: str = function.__module__
+    name: str = function.__name__
+    prefix = 'async ' * asyncio.iscoroutinefunction(function)
+    signature = signature if len(signature) < 48 else '(...)'
 
-    return f'{function.__name__}{function_signature}'
+    if module not in {'__main__'}:
+        return f'{prefix}{module}.{name}{signature}'
+
+    return f'{prefix}{name}{signature}'
 
 
 @contextlib.contextmanager
@@ -80,7 +85,7 @@ def analyze_stack(stack: List[Frame]):
         f'{CHAR_INFO} Finished transaction: {uuid.uuid4().hex}, '
         f'{total_time_seconds:.2f} seconds')
     print()
-    print(f'{"#":>6} {"Timestamp":>9} {"%":>6} {"Total":>9} Nested Call Chain')
+    print('  #    Timestamp      %     Total    Nested Call Chain')
     print()
 
     counter: int = 0
@@ -128,11 +133,14 @@ def _get_wrapper(  # noqa: MC001
 
     def decorator(function: Callable) -> Callable:
 
-        if not do_trace:
+        if not do_trace or not DO_TRACE.get():
 
             # No overhead is introduced
             wrapper = function
 
+            # Any downstream tracer is also disabled
+            DO_TRACE.set(False)
+
         elif asyncio.iscoroutinefunction(function):
 
             @functools.wraps(function)
